==> 0.5.0.tar.gz: example/lib/cell.dart <==
import 'package:fc_components/fc_cell.dart';
import 'package:fc_components/util/adapt.dart';
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';

class Cell extends StatefulWidget {
  const Cell({Key? key}) : super(key: key);

  @override
  _CellState createState() => _CellState();
}

class _CellState extends State<Cell> {
  String cacheSizeStr = '';
  bool canCheckBiometrics = false;
  bool localauthBind = false;

  @override
  void initState() {
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: const Text('FcCell 单元格'),
      ),
      body: ListView(
        children: [
          /// 完整示例
          Padding(
            padding: EdgeInsets.all(Adapt.px(20)),
            child: const Text('完整示例'),
          ),
          FcCell(
            onPressed: () {},
            label: const Text('我是 label'),
            content: const Text('我是 content'),
          ),

          /// content 靠左
          Padding(
            padding: EdgeInsets.all(Adapt.px(20)),
            child: const Text('content 靠左'),
          ),
          FcCell(
            onPressed: () {},
            label: const Text('我是 label'),
            content: const Text('我是 content'),
            contentAlignment: Alignment.centerLeft,
          ),

          /// 无 border
          Padding(
            padding: EdgeInsets.all(Adapt.px(20)),
            child: const Text('无 border'),
          ),
          FcCell(
            onPressed: () {},
            label: const Text('我是 label'),
            content: const Text('我是 content'),
            border: false,
          ),

          /// 无右侧箭头
          Padding(
            padding: EdgeInsets.all(Adapt.px(20)),
            child: const Text('无右侧箭头'),
          ),
          FcCell(
            onPressed: () {},
            label: const Text('我是 label'),
            content: const Text('我是 content'),
            arrow: false,
          ),

          /// 仅 label，无点击态
          Padding(
            padding: EdgeInsets.all(Adapt.px(20)),
            child: const Text('仅 label，无点击态'),
          ),
          const FcCell(
            label: Text('我是 label'),
            arrow: false,
          ),

          /// 长 content
          Padding(
            padding: EdgeInsets.all(Adapt.px(20)),
            child: const Text('长 content'),
          ),
          FcCell(
            onPressed: () {},
            label: const Text('我是 label'),
            content: const Text(
              '我是 content我是 content我是 content我是 content我是 content我是 content我是 content',
            ),
          ),

          /// 长 content，顶部对齐
          Padding(
            padding: EdgeInsets.all(Adapt.px(20)),
            child: const Text('长 content，顶部对齐'),
          ),
          FcCell(
            onPressed: () {},
            crossAxisAlignment: CrossAxisAlignment.start,
            label: const Text('我是 label'),
            content: const Text(
              '我是 content我是 content我是 content我是 content我是 content我是 content我是 content',
            ),
          ),
        ],
      ),
    );
  }
}

==> 0.5.8.tar.gz: example/lib/cell.dart <==
import 'package:fc_components/fc_cell.dart';
import 'package:fc_components/util/adapt.dart';
import 'package:flutter/material.dart';

class Cell extends StatefulWidget {
  const Cell({Key? key}) : super(key: key);

  @override
  _CellState createState() => _CellState();
}

class _CellState extends State<Cell> {
  String cacheSizeStr = '';
  bool canCheckBiometrics = false;
  bool localauthBind = false;

  @override
  void initState() {
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: const Text('FcCell 单元格'),
      ),
      body: ListView(
        children: [
          /// 完整示例
          Padding(
            padding: EdgeInsets.all(Adapt.px(20)),
            child: const Text('完整示例'),
          ),
          FcCell(
            onPressed: () {},
            label: const Text('我是 label'),
            content: const Text('我是 content'),
          ),

          /// content 靠左
          Padding(
            padding: EdgeInsets.all(Adapt.px(20)),
            child: const Text('content 靠左'),
          ),
          FcCell(
            onPressed: () {},
            label: const Text('我是 label'),
            content: const Text('我是 content'),
            contentAlignment: Alignment.centerLeft,
          ),

          /// 无 border
          Padding(
            padding: EdgeInsets.all(Adapt.px(20)),
            child: const Text('无 border'),
          ),
          FcCell(
            onPressed: () {},
            label: const Text('我是 label'),
            content: const Text('我是 content'),
            border: false,
          ),

          /// 无右侧箭头
          Padding(
            padding: EdgeInsets.all(Adapt.px(20)),
            child: const Text('无右侧箭头'),
          ),
          FcCell(
            onPressed: () {},
            label: const Text('我是 label'),
            content: const Text('我是 content'),
            arrow: false,
          ),

          /// 仅 label，无点击态
          Padding(
            padding: EdgeInsets.all(Adapt.px(20)),
            child: const Text('仅 label，无点击态'),
          ),
          const FcCell(
            label: Text('我是 label'),
            arrow: false,
          ),

          /// 长 content
          Padding(
            padding: EdgeInsets.all(Adapt.px(20)),
            child: const Text('长 content'),
          ),
          FcCell(
            onPressed: () {},
            label: const Text('我是 label'),
            content: const Text(
              '我是 content我是 content我是 content我是 content我是 content我是 content我是 content',
            ),
          ),

          /// 长 content，居中
          Padding(
            padding: EdgeInsets.all(Adapt.px(20)),
            child: const Text('长 content，居中'),
          ),
          FcCell(
            onPressed: () {},
            crossAxisAlignment: CrossAxisAlignment.center,
            label: const Text('我是 label'),
            content: const Text(
              '我是 content我是 content我是 content我是 content我是 content我是 content我是 content',
            ),
          ),

          /// 最右侧扩展内容
          Padding(
            padding: EdgeInsets.all(Adapt.px(20)),
            child: const Text('最右侧扩展内容'),
          ),
          FcCell(
            onPressed: () {},
            crossAxisAlignment: CrossAxisAlignment.center,
            label: const Text('我是 label'),
            arrow: false,
            extra: const Text(
              '扩展内容',
              style: TextStyle(color: Color(0xFF666666)),
            ),
          ),
        ],
      ),
    );
  }
}
